# Copyright (c) 2000-2011, JPackage Project
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions
# are met:
#
# 1. Redistributions of source code must retain the above copyright
#    notice, this list of conditions and the following disclaimer.
# 2. Redistributions in binary form must reproduce the above copyright
#    notice, this list of conditions and the following disclaimer in the
#    documentation and/or other materials provided with the
#    distribution.
# 3. Neither the name of the JPackage Project nor the names of its
#    contributors may be used to endorse or promote products derived
#    from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
# "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
# LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
# A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
# OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
# DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
# THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
# OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
#

#no jars in this native build, so skip copying
%define _jarsign_opts --nocopy

%define with()          %{expand:%%{?with_%{1}:1}%%{!?with_%{1}:0}}
%define without()       %{expand:%%{?with_%{1}:0}%%{!?with_%{1}:1}}
%define bcond_with()    %{expand:%%{?_with_%{1}:%%global with_%{1} 1}}
%define bcond_without() %{expand:%%{!?_without_%{1}:%%global with_%{1} 1}}

%bcond_with repolib
%if "%{?rhel}" == "6"
%bcond_without zip
%else
%bcond_with zip
%endif

%define repodir %{_javadir}/repository.jboss.com/org/hornetq/natives/%{namedversion}-brew/RHEL-%{?rhel}/
%ifarch x86_64
%define repodirlib %{repodir}/x86_64
%else
%define repodirlib %{repodir}/i386
%endif
%define repodirsrc %{repodir}/src
# jbhomedir is /usr/share/jbossas  (files must be immutable)
%define jbhomedir %{_datadir}/jbossas
%define hqnativedir modules/system/layers/base/org/hornetq/main/lib
# jbossdir is /var/lib/jbossas  (any mutable files must go here)
%define jbossdir %{_localstatedir}/lib/jbossas


%define reltag .Final
%define namedversion %{version}%{reltag}

Name:		hornetq-native
Summary: 	Open source project to build a multi-protocol, embeddable, very high performance, clustered, asynchronous messaging system
Version: 	2.3.25
Release: 	3%{reltag}_redhat_1%{?dist}
Epoch:		0
License: 	ASL 2.0
Group: 		Development/Java
URL:		http://jboss.org/hornetq/
# rm -fr hornetq
# git clone git://git.app.eng.bos.redhat.com/hornetq/hornetq.git
# cd hornetq && git checkout 2.3.25.Final-redhat-1 && cd ..
# HEAD is now at ba8483c... Add jandex support
# rm -fr hornetq/.git hornetq/.gitignore
# tar cjf hornetq-2.3.25.Final-src.tar.gz hornetq
Source0:        hornetq-%{namedversion}-src.tar.gz

BuildRequires:  autoconf, automake, libtool
BuildRequires:  libaio, libaio-devel

%if "%{?rhel}" == "7"
BuildRequires:  java6-devel
%else
BuildRequires:  java-devel
%endif
BuildRequires:  hornetq, jboss-logging

Requires(pre):  shadow-utils

%if %with zip
BuildRequires: zip
%endif

BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root
%if "%{?rhel}" == "7"
#64 bit only natives on RHEL 7
ExcludeArch:   i686 i386
%endif

%description
HornetQ is an open source project to build a multi-protocol, embeddable, very
high performance, clustered, asynchronous messaging system. HornetQ is the 
new ultra high performance enterprise grade messaging system from JBoss, 
sets a record breaking score in the SPECjms2007 industry standard benchmark 
for JMS messaging system performance.
HornetQ provides message persistence using its own built-in, high 
performance journal. HornetQ has no dependency on clunky, slow, relational
databases for persistence. The journal is a unique piece of technology 
that automatically detects if running on Linux and uses Linux Asynchronous 
IO (AIO) via a native code layer for astonishing performance. If AIO is not
available seamlessly falls back to using Java NIO, so will run seamlessly 
on any Java platform.

%package -n jbossas-hornetq-native
Summary:     HornetQ native library for JBoss EAP 6.
Group:       Development

%description -n jbossas-hornetq-native
HornetQ native library for JBoss EAP 6.


%if %with repolib
%package repolib
Summary:        Artifacts to be uploaded to a repository library
Group:          Development/Libraries

%description repolib
Artifacts to be uploaded to a repository library.
This package is not meant to be installed but so its contents
can be extracted through rpm2cpio.
%endif

%if %with zip
%package zip
Summary:        Container for the zipped distribution of %{name}.
Group:          Development

%description zip
Container for the zipped distribution of %{name}.
This package is not meant to be installed but so its contents
can be extracted through rpm2cpio.
%endif

%prep
%setup -q -n hornetq

%{_bindir}/find -type f -name "*jar" -name "*so" | %{_bindir}/xargs -t %{__rm} -fr
#for i in `%{_bindir}/find . -name pom.xml`; do sed -i -e "s:<version>2.2.0.CR1</version>:<version>2.2.1.GA</version>:" $i; done

%if %with zip
zip -q -r %{name}-%{version}-src.zip hornetq-native/*
%endif

%build
export LANG=en_US.UTF-8
export JAVA_HOME=/usr/lib/jvm/java

pushd hornetq-native/src
javah -classpath $(build-classpath hornetq-journal):$(build-classpath jboss-logging) org.hornetq.core.asyncio.impl.AsynchronousFileImpl
popd

pushd hornetq-native
#./bootstrap
autoreconf --install
%configure
make clean
make
popd

%install
%{__rm} -rf %{buildroot}
install -d -m 755 $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}
install -d -m 755 $RPM_BUILD_ROOT%{_libdir}

%ifarch i386 i686
libdir=lib
archdir=linux-i686
%endif
%ifarch ppc64
libdir=lib64
archdir=linux-ppc64
%endif
%ifarch x86_64
libdir=lib64
archdir=linux-x86_64
%endif

cp distribution/hornetq/src/main/resources/licenses/LICENSE.txt $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}/
cp NOTICE $RPM_BUILD_ROOT%{_docdir}/%{name}-%{version}/
cp -P hornetq-native/src/.libs/libHornetQAIO.so* $RPM_BUILD_ROOT%{_libdir}/
cp -p hornetq-native/src/libHornetQAIO.la $RPM_BUILD_ROOT%{_libdir}/
install -d -m 755 $RPM_BUILD_ROOT/%{jbhomedir}/%{hqnativedir}/$archdir
cp -L $RPM_BUILD_ROOT%{_libdir}/libHornetQAIO.so $RPM_BUILD_ROOT/%{jbhomedir}/%{hqnativedir}/$archdir/

# repolib
%if %with repolib
	tag=`echo %{version}-brew`
	sed -i "s/@VERSION@/$tag/g" %{SOURCE2}
	tag=`echo %{name}-%{version}-%{release} | sed 's|\.|_|g'`
	sed -i "s/@TAG@/$tag/g" %{SOURCE2}
        install -d -m 755 $RPM_BUILD_ROOT%{repodir}
        install -d -m 755 $RPM_BUILD_ROOT%{repodirlib}
        install -d -m 755 $RPM_BUILD_ROOT%{repodirsrc}
        install -m 755 %{SOURCE0} $RPM_BUILD_ROOT%{repodirsrc}
        cp -p $RPM_BUILD_ROOT%{_libdir}/*.{la,so.0.0.0} $RPM_BUILD_ROOT%{repodirlib}
%endif

%if %with zip
install -dm 755 $RPM_BUILD_ROOT/%{_javadir}/jbossas-fordev/
install -m 644 *.zip $RPM_BUILD_ROOT/%{_javadir}/jbossas-fordev
%endif

%clean
rm -Rf $RPM_BUILD_ROOT

%pre -n jbossas-hornetq-native
%if 0%{?rhel} >= 6
getent group jboss >/dev/null || groupadd -f -g 185 -r jboss
if ! getent passwd jboss >/dev/null ; then
    if ! getent passwd 185 >/dev/null ; then
      useradd -r -u 185 -g jboss -d %{jbossdir} -s /sbin/nologin -c "JBoss" jboss
    else
      useradd -r -g jboss -d %{jbossdir} -s /sbin/nologin -c "JBoss" jboss
    fi
fi
exit 0
%else
getent group jboss >/dev/null || groupadd -r jboss
getent passwd jboss >/dev/null || \
    useradd -r -g jboss -d %{jbossdir} -s /sbin/nologin \
    -c "JBoss" jboss
exit 0
%endif

%files
%defattr(0644,root,root,0755)
%doc %dir %{_docdir}/%{name}-%{version}
%doc %{_docdir}/%{name}-%{version}/LICENSE.txt
%doc %{_docdir}/%{name}-%{version}/NOTICE
%{_libdir}/libHornetQ*

%files -n jbossas-hornetq-native
%defattr(0644,jboss,jboss,0755)
%dir %{_datadir}/jbossas
%dir %{_datadir}/jbossas/modules
%dir %{_datadir}/jbossas/modules/system
%dir %{_datadir}/jbossas/modules/system/layers
%dir %{_datadir}/jbossas/modules/system/layers/base
%dir %{_datadir}/jbossas/modules/system/layers/base/org
%dir %{_datadir}/jbossas/modules/system/layers/base/org/hornetq
%dir %{_datadir}/jbossas/modules/system/layers/base/org/hornetq/main
%dir %{_datadir}/jbossas/modules/system/layers/base/org/hornetq/main/lib
%dir %{jbhomedir}/%{hqnativedir}/*/
%{jbhomedir}/%{hqnativedir}/*

%if %with repolib
%files repolib
%defattr(0644,root,root,0755)
%{_javadir}*/repository.jboss.com
%endif

%if %with zip
%files zip
%defattr(-,root,root,-)
%dir %{_javadir}/jbossas-fordev
%{_javadir}/jbossas-fordev/*.zip
%endif

%changelog
* Wed Mar 11 2015  Permaine Cheung <pcheung@redhat.com> 0:2.3.25-3.Final_redhat_1
- Fix define for jbossdir

* Fri Mar 06 2015  Permaine Cheung <pcheung@redhat.com> 0:2.3.25-2.Final_redhat_1
- use soft static allocation for user and group
- fall back to dynamic user and group allocation for RHEL 5 and under

* Fri Jan 23 2015  Permaine Cheung <pcheung@redhat.com> 0:2.3.25-1.Final_redhat_1
- 2.3.25.Final-redhat-1

* Mon Nov 24 2014  Permaine Cheung <pcheung@redhat.com> 0:2.3.24-1.Final_redhat_1
- 2.3.24.Final-redhat-1

* Fri Nov 21 2014  Permaine Cheung <pcheung@redhat.com> 0:2.3.23-1.Final_redhat_1
- 2.3.23.Final-redhat-1

* Fri Jul 11 2014  Permaine Cheung <pcheung@redhat.com> 0:2.3.20-2.Final_redhat_1
- Rebuild

* Wed Jul 02 2014  Permaine Cheung <pcheung@redhat.com> 0:2.3.20-1_Final.redhat_1
- 2.3.20.Final-redhat-1

* Thu May 29 2014  Permaine Cheung <pcheung@redhat.com> 0:2.3.19-1_Final.redhat_1
- 2.3.19.Final-redhat-1

* Fri Mar 28 2014  Permaine Cheung <pcheung@redhat.com> 0:2.3.18-2_Final.redhat_1
- Rebuild on RHEL 7 as ppc64 builders are enabled

* Fri Mar 28 2014  Permaine Cheung <pcheung@redhat.com> 0:2.3.18-1_Final.redhat_1
- 2.3.18.Final-redhat-1
- ppc64 support

* Tue Sep 17 2013  Permaine Cheung <pcheung@redhat.com> 0:2.3.8-1_Final.redhat_1
- HornetQ_2_3_8_Final

* Wed Sep 11 2013  Permaine Cheung <pcheung@redhat.com> 0:2.3.7-1_Final.redhat_1
- HornetQ_2_3_7_Final

* Mon Aug 19 2013  Permaine Cheung <pcheung@redhat.com> 0:2.3.5-1_Final.redhat_1
- HornetQ_2_3_5_Final

* Thu Aug 15 2013  Permaine Cheung <pcheung@redhat.com> 0:2.3.4-1_Final.redhat_1
- HornetQ_2_3_4_Final

* Fri Aug 09 2013  Permaine Cheung <pcheung@redhat.com> 0:2.3.3-1_Final.redhat_1
- HornetQ_2_3_3_FINAL

* Mon Jul 15 2013  Permaine Cheung <pcheung@redhat.com> 0:2.3.2-1_Final.redhat_1
- HornetQ_2_3_2_FINAL

* Mon May 06 2013  Permaine Cheung <pcheung@redhat.com> 0:2.3.1-1_Final.redhat_1
- HornetQ_2_3_1_FINAL

* Thu Apr 25 2013  Permaine Cheung <pcheung@redhat.com> 0:2.3.0-5_Final.redhat_1
- HornetQ_2_3_0_FINAL

* Mon Apr 15 2013  Permaine Cheung <pcheung@redhat.com> 0:2.3.0-4_CR2.redhat_1
- Remove R: j-m-eap and own all dirs instead

* Thu Mar 28 2013  Permaine Cheung <pcheung@redhat.com> 0:2.3.0-3_CR2.redhat_1
- Uncomment R:jbossas-modules-eap
- Fix %%files

* Thu Mar 28 2013  Permaine Cheung <pcheung@redhat.com> 0:2.3.0-2_CR2.redhat_1
- new native dir name
- 2.3.0.CR2

* Tue Feb 19 2013  Permaine Cheung <pcheung@redhat.com> 0:2.3.0-1_CR1.redhat_1
- Merge with ep-6-rhel-5 branch
- Add .redhat_1 to Release: tag
- EAP 6.1.0.ER1 build
- Temporarily commented out R:j-m-e until it is built for 6.1.0
- Update path for hq natives for 6.1.0
- 2.3.0.CR1

* Wed Oct 03 2012 Permaine Cheung <pcheung@redhat.com> 0:2.2.21-1.Final
- 2.2.21.Final

* Thu Sep 13 2012 Permaine Cheung <pcheung@redhat.com> 0:2.2.19-1.Final
- HornetQ_2_2_19_AS7_Final_build2

* Fri Sep 07 2012 Permaine Cheung <pcheung@redhat.com> 0:2.2.16-3.Final
- Add src zip

* Tue May 22 2012 Permaine Cheung <pcheung@redhat.com> 0:2.2.16-2.Final
- Fix jbhomedir in jbossas-hornetq-native

* Tue May 15 2012 Permaine Cheung <pcheung@redhat.com> 0:2.2.16-1.Final
- Upgrade to 2.2.16.Final

* Tue Mar 20 2012 Permaine Cheung <pcheung@redhat.com> 0:2.2.12-2.Final
- Fix dirname in jbossas-hornetq-native subpackage

* Tue Mar 06 2012 Permaine Cheung <pcheung@redhat.com> 0:2.2.12-1.Final
- 2.2.12.Final

* Fri Feb 24 2012 Permaine Cheung <pcheung@redhat.com> 0:2.2.11-3.Final
- Add flag to build with hornetq

* Tue Feb 21 2012 Permaine Cheung <pcheung@redhat.com> 0:2.2.11-2.Final
- Fix R: jbossas-hornetq-native
- Fix depmap

* Fri Feb 17 2012 Permaine Cheung <pcheung@redhat.com> 0:2.2.11-1.Final
- 2.2.11.Final
- Merge with hornetq/jb-eap-6-rhel-6 build

* Wed Jan 25 2012 Permaine Cheung <pcheung@redhat.com> 0:2.2.8-2.CR2
- Add jbossas-hornetq-native subpackage

* Wed Nov 30 2011 Permaine Cheung <pcheung@redhat.com> 0:2.2.8-1.CR2
- Upgrade to 2.2.8.CR2
- Merge with hornetq/JB-EAP-6-RHEL-6

* Mon Sep 12 2011 Permaine Cheung <pcheung@redhat.com> 0:2.2.8-1.CR1.1
- Upgrade to 2.2.8.CR1

* Tue Apr 12 2011 Permaine Cheung <pcheung@redhat.com> 0:2.2.2-2.GA.2
- Fix location of library so that it is multilib-clean

* Mon Mar 28 2011 Permaine Cheung <pcheung@redhat.com> 0:2.2.2-1.GA.1
- 2.2.2.GA

* Wed Mar 16 2011 Permaine Cheung <pcheung@redhat.com> 0:2.2.1-1.GA.3
- 2.2.1.GA

* Wed Mar 09 2011 Permaine Cheung <pcheung@redhat.com> - 0:2.2.0-2.GA.2
- Rebuild on RHEL 6 with 2.2.0.GA
- Remove patch already incorporated in source

* Tue Feb 01 2011 David Walluck <dwalluck@redhat.com> 0:2.2.0-0.1.CR1.2
- add patch to keep maven from going online for jar-rest
- add workaround for thirdparty build on maven 2.0.8
- update jpp-depmap.xml to allow building on JPackage 6
- BuildRequires: jboss-ejb3-build >= 0:1.0.0
- remove build root before install
- set LANG in case of unmappable characters

* Mon Jan 24 2011 Permaine Cheung <pcheung@redhat.com> - 0:2.1.2-1.Final.0.2
- Add zip subpackage

* Mon Dec 13 2010 Fernando Nasser <fnasser@redhat.com> - 0:2.1.2-1.Final.0.1.2
- Add patch to build on i386

* Wed Aug 18 2010 Permaine Cheung <pcheung@redhat.com> - 0:2.1.2-1.Final.0.1.1
- Upgrade to 2.1.2.Final

* Wed Jun 16 2010 Permaine Cheung <pcheung@redhat.com> - 0:2.1.1-1.Final.0.1
- Upgrade to 2.1.1.Final

* Fri Jun 04 2010 Permaine Cheung <pcheung@redhat.com> - 0:2.1.0-2.Final
- Build from 2.1.0.Final tag

* Mon May 31 2010 Permaine Cheung <pcheung@redhat.com> - 0:2.1.0-1.CR1
- Build from 2.1.0.CR1 tag

* Mon May 17 2010 Permaine Cheung <pcheung@redhat.com> - 0:2.0.0-1.3.CR3
- Update to the latest trunk for a RHEL 4 bug fix

* Wed May 12 2010 Permaine Cheung <pcheung@redhat.com> - 0:2.0.0-1.2.CR3
- Fix cp command

* Wed May 12 2010 Permaine Cheung <pcheung@redhat.com> - 0:2.0.0-1.1.CR3
- Create symlinks for library

* Mon May 10 2010 Permaine Cheung <pcheung@redhat.com> - 0:2.0.0-1.CR3
- First release
